Coverage for /Users/eugene/Development/legion-utils/legion_utils/__init__.py: 100%

1 from .core import (NotificationMsg,

2 InfoMsg,

3 ActivityMsg,

4 AlertMsg,

5 WarningMsg,

6 ErrorMsg,

7 CriticalMsg,

8 Priority,

9 broadcast,

10 broadcast_msg,

11 broadcast_alert_msg,

12 broadcast_info,

13 broadcast_activity,

14 broadcast_alert,

15 broadcast_warning,

16 broadcast_error,

17 broadcast_critical,

18 priority_of,

19 valid_priority)

20 from .instrumentation import Service, Periodic

21 from robotnikmq.log import log

22

23# Constants

24 SECONDS = 1

25 MINUTES = 60 * SECONDS

26 HOURS = 60 * MINUTES

27 DAYS = 24 * HOURS

28 WEEKS = 7 * DAYS